@@ -215,12 +215,12 @@ class Operation:
                                            attributes, successors, regions)
 
     @classmethod
-    def build(cls: typing.Type[T],
+    def build(cls: typing.Type[OperationType],
               operands=[],
               result_types=[],
               attributes=[],
               successors=[],
-              regions=[]) -> T:
+              regions=[]) -> OperationType:
         """Create a new operation using builders."""
         ...
 
@@ -283,7 +283,7 @@ class Block:
 
     @staticmethod
     def from_callable(block_arg_types: List[Attribute],
-                      f: Callable[[Attribute, ...], List[Operation]]):
+                      f: Callable[[BlockArgument, ...], List[Operation]]):
         b = Block.from_arg_types(block_arg_types)
         b.add_ops(f(*b.args))
         return b
@@ -342,7 +342,7 @@ class Region:
             return arg
         if isinstance(arg, list):
             if len(arg) == 0:
-                raise ValueError("Can't construct a region with an empty list")
+                return Region.from_operation_list([])
             if isinstance(arg[0], Block):
                 return Region.from_block_list(arg)
             if isinstance(arg[0], Operation):
