@@ -247,9 +247,10 @@ class AttributeDef:
 def get_variadic_sizes(op: Operation, is_operand: bool) -> List[int]:
     """Get variadic sizes of operands or results."""
 
-    # We need irdl to define VectorAttr, but here we need VectorAttr.
+    # We need irdl to define DenseIntOrFPElementsAttr, but here we need
+    # DenseIntOrFPElementsAttr.
     # So we have a circular dependency that we solve by importing in this function.
-    from xdsl.dialects.builtin import VectorAttr
+    from xdsl.dialects.builtin import DenseIntOrFPElementsAttr
 
     operand_or_result_defs = op.irdl_operand_defs if is_operand else op.irdl_result_defs
     variadic_defs = [(arg_name, arg_def)
@@ -270,9 +271,9 @@ def get_variadic_sizes(op: Operation, is_operand: bool) -> List[int]:
                 f"Expected {size_attribute_name} attribute in {op.name} operation."
             )
         attribute = op.attributes[size_attribute_name]
-        if not isinstance(attribute, VectorAttr):
+        if not isinstance(attribute, DenseIntOrFPElementsAttr):
             raise Exception(
-                f"{size_attribute_name} attribute is expected to be a VectorAttr."
+                f"{size_attribute_name} attribute is expected to be a DenseIntOrFPElementsAttr."
             )
         variadic_sizes = [
             size_attr.value.data for size_attr in attribute.data.data
@@ -417,13 +418,9 @@ def irdl_build_attribute(irdl_def: AttrConstraint, result) -> Attribute:
         if isinstance(result, Tuple):
             return irdl_def.attr.build(*result)
         return irdl_def.attr.build(result)
-    elif irdl_def == AnyAttr():
-        if isinstance(result, Attribute):
-            return result
-        raise Exception(f"builder expected an attribute, got {result}")
-    else:
-        raise NotImplementedError(
-            f"Builder does not support IRDL definition {irdl_def}")
+    if isinstance(result, Attribute):
+        return result
+    raise Exception(f"builder expected an attribute, got {result}")
 
 
 OpT = TypeVar('OpT', bound='Operation')
@@ -437,9 +434,10 @@ def irdl_op_builder(cls: typing.Type[OpT], operands: List,
                     regions, options) -> OpT:
     """Builder for an irdl operation."""
 
-    # We need irdl to define VectorAttr, but here we need VectorAttr.
+    # We need irdl to define DenseIntOrFPElementsAttr, but here we need
+    # DenseIntOrFPElementsAttr.
     # So we have a circular dependency that we solve by importing in this function.
-    from xdsl.dialects.builtin import VectorAttr, IntegerAttr
+    from xdsl.dialects.builtin import DenseIntOrFPElementsAttr, IntegerAttr, VectorType, IntegerType, i32
 
     # Build operands by forwarding the values to SSAValue.get
     if len(operand_defs) != len(operands):
@@ -498,7 +496,7 @@ def irdl_op_builder(cls: typing.Type[OpT], operands: List,
             if isinstance(operand_def, VarOperandDef)
         ]
         built_attributes[AttrSizedOperandSegments.attribute_name] =\
-            VectorAttr.from_list([IntegerAttr.from_index_int_value(size) for size in sizes])
+            DenseIntOrFPElementsAttr.vector_from_list(sizes, i32)
 
     if AttrSizedResultSegments() in options:
         sizes = [
@@ -507,7 +505,7 @@ def irdl_op_builder(cls: typing.Type[OpT], operands: List,
             if isinstance(result_def, VarResultDef)
         ]
         built_attributes[AttrSizedResultSegments.attribute_name] =\
-            VectorAttr.from_list([IntegerAttr.from_index_int_value(size) for size in sizes])
+            DenseIntOrFPElementsAttr.vector_from_list(sizes, i32)
 
     # Build regions using `Region.get`.
     regions = [Region.get(region) for region in regions]
@@ -530,19 +528,23 @@ def irdl_op_definition(
         cls,
         Operation), f"class {cls.__name__} should be a subclass of Operation"
 
+    # Get all fields of the class, including the parent classes
+    clsdict = dict()
+    for parent_cls in cls.mro():
+        clsdict = {**clsdict, **parent_cls.__dict__}
+
     operand_defs = [(field_name, field)
-                    for field_name, field in cls.__dict__.items()
+                    for field_name, field in clsdict.items()
                     if isinstance(field, OperandDef)]
     result_defs = [(field_name, field)
-                   for field_name, field in cls.__dict__.items()
+                   for field_name, field in clsdict.items()
                    if isinstance(field, ResultDef)]
     region_defs = [(field_name, field)
-                   for field_name, field in cls.__dict__.items()
+                   for field_name, field in clsdict.items()
                    if isinstance(field, RegionDef)]
-    attr_defs = [(field_name, field)
-                 for field_name, field in cls.__dict__.items()
+    attr_defs = [(field_name, field) for field_name, field in clsdict.items()
                  if isinstance(field, AttributeDef)]
-    options = cls.__dict__.get("irdl_options", [])
+    options = clsdict.get("irdl_options", [])
     new_attrs = dict()
 
     # Add operand access fields
@@ -586,8 +588,8 @@ def irdl_op_definition(
 
     new_attrs["verify_"] = lambda op: irdl_op_verify(
         op, operand_defs, result_defs, region_defs, attr_defs)
-    if "verify_" in cls.__dict__:
-        custom_verifier = cls.__dict__["verify_"]
+    if "verify_" in clsdict:
+        custom_verifier = clsdict["verify_"]
 
         def new_verifier(verifier, op):
             verifier(op)
